package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````8"````````!``````````&BQ````
M`````````$``.``)`$``'``;``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````<`````````!P``````````0`````````!````
M!0```````````````````````````````````,"=````````P)T`````````
M`"````````$````&````D*L```````"0JR```````)"K(```````D`0`````
M```8%0``````````(````````@````8```"XJP```````+BK(```````N*L@
M```````0`@```````!`"````````"``````````$````!````%0"````````
M5`(```````!4`@```````$0`````````1``````````$`````````%#E=&0$
M````V)8```````#8E@```````-B6````````[`````````#L``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````)"K````````D*L@``````"0JR``
M`````'`$````````<`0````````!`````````"]L:6(V-"]L9"UL:6YU>"UX
M.#8M-C0N<V\N,@`$````$`````$```!'3E4```````,````"``````````0`
M```4`````P```$=.50!1S#4THF?O:S@U45"(ZX(?^89!XQ$```!$````!```
M``@````@'!``!4`$AB@"0`"0A@"`@BD`($D@!`FXHAA-N@0&"@````!$````
M2````$P```!-````5````%4```!7````6P```%P`````````7@```&$```!B
M````8P``````````````;L7?'^K3[P[.WD<M:W^:?"[%F[8@_^0.N(WQ#M5D
MU'S9<5@<XD?&`:Q+X\#RV],=NN.2?,+E/RSZH6Q@LP&+;VL)0]9FK\QFQ;F<
M0$)%U>S$B060B`=PTSGRBQP-%.*>VLWCGC-BV^T,.I<+5J2;EJ?=HVM_J9R;
MX:<""@J*$%>CX/M)````````````````````````````````$0$``!(`````
M````````````````````YP$``!(`````````````````````````70(``!(`
M````````````````````````.P(``!(`````````````````````````$0``
M`"``````````````````````````9`(``!(`````````````````````````
M\`(``!(`````````````````````````M````!(`````````````````````
M````>0(``!(`````````````````````````@P$``!(`````````````````
M````````V`(``!(`````````````````````````T`(``!(`````````````
M````````````A````!(`````````````````````````L0,``!(`````````
M````````````````#`$``!(`````````````````````````G`(``!(`````
M````````````````````C@(``!(`````````````````````````3`(``!(`
M````````````````````````Z0(``!(`````````````````````````!@,`
M`!(`````````````````````````9P$``!(`````````````````````````
M-0$``!(`````````````````````````P@```!(`````````````````````
M````L0$``!(`````````````````````````%`(``!(`````````````````
M````````0P(``!(`````````````````````````)`(``!(`````````````
M````````````G@$``!(`````````````````````````<@(``!(`````````
M````````````````X@$``!(`````````````````````````2@,``!(`````
M````````````````````0P,``!(`````````````````````````0P$``!(`
M````````````````````````^0(``!(`````````````````````````+0``
M`"``````````````````````````L`(``!(`````````````````````````
M9````!(```````````````````````````(``!(`````````````````````
M````J@$``!(`````````````````````````DP```!(`````````````````
M````````GP```!(`````````````````````````7`$``!(`````````````
M````````````(@$``!(`````````````````````````5@```!(`````````
M````````````````%@$``!(`````````````````````````MP(``!(`````
M````````````````````DP$``!(`````````````````````````\````!(`
M````````````````````````:@(``!(`````````````````````````VP$`
M`!(`````````````````````````-`,``!(`````````````````````````
M#0,``!(`````````````````````````=0$``!(`````````````````````
M````<P```!(`````````````````````````/`,``!(`````````````````
M````````AP(``!(`````````````````````````U````!(`````````````
M````````````4P$``!(`````````````````````````Q0(``!(`````````
M````````````````-@(``!(`````````````````````````^`$``!(`````
M````````````````````H@(``!(`````````````````````````/````"``
M````````````````````````@`(``!(`````````````````````````%P,`
M`"(`````````````````````````E0(``!(`````````````````````````
M)@,``!(`````````````````````````N@,``!(`#@"`5@```````'``````
M````B`,``!(`#P!T5P``````````````````WP,``!(`#@`P1@```````%0,
M````````5P,``!(`#@`P'@```````"T"````````C@,``!(`#@!P/P``````
M``4`````````300``!(`#@"`/P```````!H"````````1P0``!(`"P!`&@``
M````````````````>@0``!(`#@"04@```````.T#````````;0,``!``&0`@
ML"``````````````````Q@,``!(`#@"@00```````"H`````````^0,``!$`
M$`"`5P````````0`````````O`$``!$`%0"@JR```````!,`````````>0,`
M`!``&0"HP"``````````````````100``!(`#@`@/@```````#``````````
M6@0``!(`#@!010```````-P`````````;`0``!(`#@"@1````````'0`````
M````[`,``!``&```L"``````````````````TP,``!(`#@#000```````.P`
M````````7`,``!$`&0!(L"````````@`````````9@,``!``&``@L"``````
M````````````70,``"$`&0!(L"````````@`````````+@0``!$`&``8L"``
M``````@`````````X@(``!$`&0!@L"````````@`````````?@,``!(`#@!P
M5P````````(`````````'@0``!(`#@``5P```````&4`````````\@,``!(`
M#@!@(````````"L`````````[@,``"``&```L"```````````````````0$`
M`!$`&0`@L"````````0`````````7@,``"$`&0!(L"````````@`````````
MGP,``!(`#@`@10```````"0`````````"`0``!(`#@"@/@```````,$`````
M````XP```!$`&0!`L"````````$`````````.`0``!(`#@#`0@```````-L!
M`````````&QI8G!E<FPN<V\N-2XR-@!?251-7V1E<F5G:7-T97)434-L;VYE
M5&%B;&4`7U]G;6]N7W-T87)T7U\`7TE435]R96=I<W1E<E1-0VQO;F5486)L
M90!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K7VQO
M8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O
M;G1E>'0`4&5R;%]A=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G<P!097)L7W-V
M7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?
M:V5Y`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`
M4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N
M97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A
M9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`
M4$Q?;65M;W)Y7W=R87``;&EB<'1H<F5A9"YS;RXP`&]P96XV-`!R96%D`%]?
M97)R;F]?;&]C871I;VX`;'-E96LV-`!P=&AR96%D7V=E='-P96-I9FEC`&-L
M;W-E`&QI8F,N<V\N-@!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-T<FYC;7``
M8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO
M8P!M96UC:'(`9V5T<&ED`'-T<F1U<`!S=')T;VL`<W1R;&5N`'-T<G-T<@!R
M;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?;'AS
M=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I9`!R96%D;&EN
M:P!?7VUE;6-P>5]C:&L`<W1R8VAR`')E861D:7(V-`!?7V-X85]F:6YA;&EZ
M90!?7W-P<FEN=&9?8VAK`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?
M<W1A<G1?;6%I;@!?7V5N=FER;VX`7V5D871A`%]?8G-S7W-T87)T`%]E;F0`
M7U]L:6)C7V-S=5]F:6YI`'!A<E]C=7)R96YT7V5X96,`9V5T7W5S97)N86UE
M7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``<&%R7V)A<V5N86UE`'!A<E]D
M:7)N86UE`'!A<E]M:W1M<&1I<@!?7V1A=&%?<W1A<G0`7TE/7W-T9&EN7W5S
M960`<&%R7V-U<G)E;G1?97AE8U]P<F]C`%]?;&EB8U]C<W5?:6YI=`!M>5]P
M87)?<&P`<&%R7VEN:71?96YV`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S
M971U<%]L:6)P871H`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS7U!!4E]"
M3T]4`$=,24)#7S(N,BXU`$=,24)#7S(N,30`1TQ)0D-?,BXS+C0`1TQ)0D-?
M,BXS+C(`1TQ)0D-?,BXT``````(``P`"``(````"``(````"`````@`"````
M`@````(``@`$``(``@````````````,``@`%`````@`#``(``@````8````'
M`````P`"``````````````````8```````(``P`"``(```````(``@``````
M`@`"``,`!@````(``@`"``8``0`!``$``0`!``$``0`!``$``0`!`````0`!
M``$``0`!``$``@`!``(``0`"``$``0`!``$````"``$``0````$```````$`
M`0#+`0``$````"````!U&FD)```#`)`$`````````0`%`!H"```0````````
M`)21E@8```<`G`0``!````!T&6D)```&`*<$```0````<AEI"0``!0"S!```
M$````!1I:0T```0`OP0``!````!U&FD)```"`)`$````````D*L@```````(
M`````````&`A````````F*L@```````(`````````"`A````````"+`@````
M```(``````````BP(```````&+`@```````(`````````*!:````````N*\@
M```````&````!0``````````````P*\@```````&````"@``````````````
MR*\@```````&````'P``````````````T*\@```````&````(P``````````
M````V*\@```````&````*P``````````````X*\@```````&````-@``````
M````````Z*\@```````&````/P``````````````\*\@```````&````00``
M````````````H*L@```````%````3P``````````````(+`@```````%````
M7P``````````````0+`@```````%````8P``````````````2+`@```````%
M````5@``````````````8+`@```````%````6@``````````````X*T@````
M```'`````0``````````````Z*T@```````'`````@``````````````\*T@
M```````'`````P``````````````^*T@```````'````!```````````````
M`*X@```````'````!@``````````````"*X@```````'````!P``````````
M````$*X@```````'````"```````````````&*X@```````'````"0``````
M````````(*X@```````'````"P``````````````**X@```````'````#```
M````````````,*X@```````'````#0``````````````.*X@```````'````
M#@``````````````0*X@```````'````#P``````````````2*X@```````'
M````$```````````````4*X@```````'````$0``````````````6*X@````
M```'````$@``````````````8*X@```````'````$P``````````````:*X@
M```````'````%```````````````<*X@```````'````%0``````````````
M>*X@```````'````%@``````````````@*X@```````'````%P``````````
M````B*X@```````'````&```````````````D*X@```````'````&0``````
M````````F*X@```````'````&@``````````````H*X@```````'````&P``
M````````````J*X@```````'````'```````````````L*X@```````'````
M'0``````````````N*X@```````'````'@``````````````P*X@```````'
M````(```````````````R*X@```````'````(0``````````````T*X@````
M```'````(@``````````````V*X@```````'````)```````````````X*X@
M```````'````)0``````````````Z*X@```````'````)@``````````````
M\*X@```````'````)P``````````````^*X@```````'````*```````````
M`````*\@```````'````*0``````````````"*\@```````'````*@``````
M````````$*\@```````'````+```````````````&*\@```````'````+0``
M````````````(*\@```````'````+@``````````````**\@```````'````
M+P``````````````,*\@```````'````,```````````````.*\@```````'
M````,0``````````````0*\@```````'````,@``````````````2*\@````
M```'````,P``````````````4*\@```````'````-```````````````6*\@
M```````'````-0``````````````8*\@```````'````-P``````````````
M:*\@```````'````.```````````````<*\@```````'````.0``````````
M````>*\@```````'````.@``````````````@*\@```````'````.P``````
M````````B*\@```````'````/```````````````D*\@```````'````/0``
M````````````F*\@```````'````/@``````````````H*\@```````'````
M0```````````````J*\@```````'````0@``````````````L*\@```````'
M````0P``````````````2(/L"$B+!865(`!(A<!T`O_02(/$",,`````````
M``#_-6J3(`#_)6R3(``/'T``_R5JDR``:`````#IX/____\E8I,@`&@!````
MZ=#_____)5J3(`!H`@```.G`_____R52DR``:`,```#IL/____\E2I,@`&@$
M````Z:#_____)4*3(`!H!0```.F0_____R4ZDR``:`8```#I@/____\E,I,@
M`&@'````Z7#_____)2J3(`!H"````.E@_____R4BDR``:`D```#I4/____\E
M&I,@`&@*````Z4#_____)1*3(`!H"P```.DP_____R4*DR``:`P```#I(/__
M__\E`I,@`&@-````Z1#_____)?J2(`!H#@```.D`_____R7RDB``:`\```#I
M\/[___\EZI(@`&@0````Z>#^____)>*2(`!H$0```.G0_O___R7:DB``:!(`
M``#IP/[___\ETI(@`&@3````Z;#^____)<J2(`!H%````.F@_O___R7"DB``
M:!4```#ID/[___\ENI(@`&@6````Z8#^____);*2(`!H%P```.EP_O___R6J
MDB``:!@```#I8/[___\EHI(@`&@9````Z5#^____)9J2(`!H&@```.E`_O__
M_R62DB``:!L```#I,/[___\EBI(@`&@<````Z2#^____)8*2(`!H'0```.D0
M_O___R5ZDB``:!X```#I`/[___\E<I(@`&@?````Z?#]____)6J2(`!H(```
M`.G@_?___R5BDB``:"$```#IT/W___\E6I(@`&@B````Z<#]____)5*2(`!H
M(P```.FP_?___R5*DB``:"0```#IH/W___\E0I(@`&@E````Z9#]____)3J2
M(`!H)@```.F`_?___R4RDB``:"<```#I</W___\E*I(@`&@H````Z6#]____
M)2*2(`!H*0```.E0_?___R4:DB``:"H```#I0/W___\E$I(@`&@K````Z3#]
M____)0J2(`!H+````.D@_?___R4"DB``:"T```#I$/W___\E^I$@`&@N````
MZ0#]____)?*1(`!H+P```.GP_/___R7JD2``:#````#IX/S___\EXI$@`&@Q
M````Z=#\____)=J1(`!H,@```.G`_/___R72D2``:#,```#IL/S___\ERI$@
M`&@T````Z:#\____)<*1(`!H-0```.F0_/___R6ZD2``:#8```#I@/S___\E
MLI$@`&@W````Z7#\____):J1(`!H.````.E@_/___R6BD2``:#D```#I4/S_
M__\EFI$@`&@Z````Z4#\____)<J1(`!FD```````````55-(@^PXB7PD'$B)
M="002(U\)!Q(B50D"$B-="002(U4)`AD2(L$)2@```!(B40D*#'`Z`C^__](
MBS5ID2``2(L]:I$@`$B)\NAR.```@#V[D2```'4OZ#3]__](A<!(B04*HB``
M#X2W`0``2(G'Z&S\__^+/7:1(`#HT?W__\:`T0@```"+/621(`#HO_W__X"(
MJ@0```*+/5*1(`#HK?W__X"(J@0```&+1"0<C7@%2+C_________'TAC_T@Y
MQP^'(@$``$C!YP-(C1U2.@``Z/G\__](BWPD$$B)!76A(`#'!7.A(``$````
M2(L72(E8"$B-'2PZ``!(B5@82(D02(L5WY`@`$B)4!"+5"0<@_H!1(U*!'XM
M1(U*!$B#QPB^!0```&8/'X0``````$R+!TACSH/&`4B#QPA!.?%,B43(^'7I
M2(L](J$@`$UCR4B--<@>``"#P@-%,<!*QT3(^`````!(B<'H8?W__X7`B<-T
M9$B+/?2@(`!(C6PD).C:^___2(T]9S@``#'`2(GNZ+D7``!(A<!T*DB+/<V@
M(`#H6/O__^CS_/__B=A(BUPD*&1(,QPE*````'5?2(/$.%M=PTB+/9N@(`!(
MA?]T+.AY-@``Z\-(BSV0H"``Z(O]__^)P^N,2(TU@(L@`$B-/:\W```QP.B"
M_/__2(T]I#<``$B)[NA#%P``2(7`2(G'2(D%3J`@`'2`Z[3H#?O__[\!````
MZ&/]__\/'P`Q[4F)T5Y(B>)(@^3P4%1,C07Z-@``2(T-@S8``$B-/:S]____
M%3Z/(`#T#Q]$``!(C3V)CR``54B-!8&/(`!(.?A(B>5T&4B+!0J/(`!(A<!T
M#5W_X&8N#Q^$``````!=PP\?0`!F+@\?A```````2(T]28\@`$B--4*/(`!5
M2"G^2(GE2,'^`TB)\$C!Z#](`<9(T?YT&$B+!>F.(`!(A<!T#%W_X&8/'X0`
M`````%W##Q]``&8N#Q^$``````"`/4&/(```=2](@SV_CB```%5(B>5T#$B+
M/<J.(`#HW?S__^A(____Q@49CR```5W##Q^``````//#9@\?1```54B)Y5WI
M9O___V8/'T0``$%7059,C4\X055!5$4QP%532('LF`(``&1(BP0E*````$B)
MA"2(`@``,<!(B>%FD$.+!`%+BS0!#\A(B?*)P$C!ZB!*B01!2(GP2,'N.$C!
MZ"@E`/\``$@)\$B)UDC!X@A(P>88@>(``/\`B?9("?!("=!*B41!"$F#P`A)
M@_A`=:Y(C;$``@``#Q^``````$B+06A(,T%`2(/!"$@S00A(,T'X2(T4`$C!
MZ!]("="#X/](B4%X2#GQ==5,BQ=(BU\02(MW($B+;QA,BT\(3(G03(G22,'J
M&TC!X`5("=`#!"2-E#"9>8):2(G82(MT)`A(,>A,(<A(,>A(C;0UF7F"6D2-
M+`),B<I,B<A(P>@"2,'B'D@)PDB)V$V)Z(G12<'H&T@QR$PAT$@QV$@!\$R)
M[DC!Y@5,"<9$C20&3(G63(G02,'F'DC!Z`)("?!(BW0D$$V)XT@QPDG!ZQM!
MB<!,(>I(C;0SF7F"6D@QRD@!\DR)YDC!Y@5,"=Y$C1P63(GN2(M4)!A)P>T"
M2,'F'DP)[D@Q\$B-E!&9>8):3(G93"'@08GV3#'`2,'I&T@!T$R)VDC!X@5(
M"<I,B>%)P>P"1(TL`DC!X1Y(BU0D($P)X4B)\$@QR$R)[D&)S$PAV$F-E!"9
M>8):2,'N&TPQ\$@!T$R)ZDC!X@5("?)$C00"3(G:2(M$)"A)P>L"2,'B'DP)
MVDR)QD@QT4F-A`:9>8):2,'N&TPAZ4&)TTPQX4@!P4R)P$C!X`5("?!$C30(
M3(GH2(M,)#!)P>T"2,'@'DP)Z$R)]D@QPDF-C`R9>8):08G%3"'"3#':2`'*
M3(GQ2,'A!4C![AM("?%,B<9)P>@"1(TD$4C!YAY(BU0D.$P)QD@Q\$R)X4&)
M\$PA\$F-E!.9>8):2,'I&TPQZ$@!T$R)XDC!X@5("<I,B?%)P>X"1(T<`DC!
MX1Y(BU0D0$P)\4B)\$@QR$R)WD&)SDPAX$F-E!69>8):2,'N&TPQP$@!T$R)
MVDC!X@5("?)$C2P"3(GB2(M$)$A)P>P"2,'B'DP)XDR)[D@QT4F-A`"9>8):
M2,'N&TPAV4&)U$PQ\4@!P4R)Z$C!X`5("?!$C00(3(G82(M,)%!)P>L"2,'@
M'DP)V$R)QD@QPDF-C`Z9>8):2,'N&TPAZD&)PTPQXD@!RDR)P4C!X05("?%,
MB>Y)P>T"1(TT$4C!YAY(BU0D6$P)[D@Q\$R)\4&)]4PAP$F-E!29>8):2,'I
M&TPQV$@!T$R)\DC!X@5("<I,B<%)P>@"1(TD`DC!X1Y(BU0D8$P)P4B)\$@Q
MR$R)YD&)R$F-E!.9>8):3"'P2,'N&TPQZ$@!T$R)XDC!X@5("?)$C1P"3(GR
M2(M$)&A(P>(>2<'N`DP)\DR)WD@QT4F-A`69>8):2,'N&TPAX4&)UDPQP4@!
MP4R)V$C!X`5("?!$C2P(3(G@2(M,)'!)P>P"2,'@'DP)X$R)[D@QPDF-C`B9
M>8):2,'N&TPAVD&)Q$PQ\D@!RDR)Z4C!X05("?%,B=Y)P>L"1(T$$4C!YAY(
MBU0D>$P)WD@Q\$R)P4&)\TPAZ$F-E!:9>8):2,'I&TPQX$@!T$R)PDC!X@5(
M"<I,B>E)P>T"1(TT`DC!X1Y(BY0D@````$P)Z4B)\$@QR$R)]D&)S4PAP$F-
ME!29>8):2,'N&TPQV$@!T$R)\DC!X@5("?)$C20"3(G"2(N$)(@```!)P>@"
M2,'B'DP)PDR)YD@QT4F-A`.9>8):2,'N&TPA\4&)T$PQZ4@!P4R)X$C!X`5(
M"?!(B[0DD````$2-'`A,B?!)P>X"2,'@'DP)\$F-M#69>8):38G=2#'"2<'M
M&XG!3"'B3#'"2`'R3(G>2,'F!4P)[HGV2`'R3(GF2<'L`DC!YAY!B=5,">9,
MBZ0DF````$@Q\$PAV$^-A""9>8):2#'(38GL2<'L&TP!P$V)Z$G!X`5-">!%
MB<!,`<!-B=A)P>L"2<'@'D&)Q$T)V$F)\XGV33'#2`.T)*@```!$,=I,BYPD
MH````$J-C!FAZ]EN38GC2<'K&T@!T4R)XDC!X@5,"=J)TD@!T4R)ZDG![0)(
MP>(>08G+3`GJ38G%18G`23'53`.$)+````!$,>A-B=U(C;0&H>O9;DR)V$G!
M[1M(P>`%3`GHB<!(`?!,B>9)P>P"2,'F'D&)Q4P)YDF)U(G223'T1#'A38GL
M2`.4)+@```!-C80(H>O9;DR)Z4G![!M(P>$%3`GAB<E)`<A,B=E)P>L"2,'A
M'D6)Q$P)V4F)\XGV23'+2`.T),````!$,=A-B>-(C90"H>O9;DR)X$G!ZQM(
MP>`%3`G8B<!(`<),B>A)P>T"2,'@'D&)TTP)Z$F)S8G)23'%2`.,),@```!%
M,>A-B=U.C80&H>O9;DR)WDG![1M(P>8%3`GNB?9,`<9-B>!)P>P"2<'@'D&)
M]4T)X$F)Q(G`33'$1#'B38GL2(V,$:'KV6Y,B>I(P>(%2<'L&T@#A"30````
M3`GBB=)(`=%,B=I)P>L"2,'B'D&)S$P)VDV)PT6)P$DQTTP#A"38````1#'>
M38GC2(VT,*'KV6Y,B>!)P>L;2,'@!4P)V(G`2`'P3(GN2<'M`DC!YAY!B<-,
M">Y)B=6)TDDQ]4@#E"3@````1#'I38G=38V$"*'KV6Y,B=E)P>T;2,'A!4P)
MZ8G)20'(3(GA2<'L`DC!X1Y%B<5,">%)B?2)]DDQS$0QX$V)[$B-E`*AZ]EN
M3(GH2<'L&TC!X`5,">")P$@!PDR)V$@#M"3H````2<'K`DC!X!Y!B=1,"=A)
MB<N)R4DQPT@#C"3P````13'838GC3HV$!J'KV6Y,B>9)P>L;2,'F!4P)WHGV
M3`'&38GH2<'M`DG!X!Y!B?--">A)B<6)P$TQQ4@#A"3X````1#'J38G=2(V,
M$:'KV6Y,B=I)P>T;2,'B!4P)ZHG22`'13(GB2<'L`DC!XAY!B<U,">)-B<1%
MB<!),=1$,>9-B>Q(C;0PH>O9;DR)Z$G![!M(P>`%3`G@B<!(`?!,B=Y(P>8>
M2<'K`DP#A"0``0``3`G>28G308G$23'SB=)(`Y0D"`$``$0QV4V)XTV-A`BA
MZ]EN3(GA2<'K&TC!X05,"=F)R4D!R$R)Z4G![0)(P>$>18G#3`GI28GUB?9)
M,<U(`[0D$`$``$0QZ$V)W4B-E`*AZ]EN3(G82<'M&TC!X`5,">B)P$@!PDR)
MX$G![`)(P>`>08G53`G@28G,B<E),<1%,>!-B>Q.C80&H>O9;DR)[DG![!M(
MP>8%3`GFB?9,`<9-B=A)P>L"2<'@'D&)]$T)V$@#C"08`0``28G#33'#B<!(
M`X0D(`$``$0QVDV)XTG!ZQM(C8P1H>O9;DR)XDC!X@5,"=J)TD@!T4R)ZDG!
M[0)(P>(>08G+3`GJ38G%18G`23'53`.$)"@!``!$,>Y-B=U(C;0PH>O9;DR)
MV$G![1M(P>`%3`GHB<!(`?!,B>9)P>P"2,'F'D&)Q4P)YDF)U(G223'T2`.4
M)#`!``!$,>%-B>Q-C80(H>O9;DR)Z4G![!M(P>$%3`GAB<E)`<A,B=E)P>L"
M2,'A'D6)Q$P)V4F)\XGV23'+1#'838GC2`.T)#@!``!(C90"H>O9;DR)X$G!
MZQM(P>`%3`G81(T<$$R)Z$G![0)(P>`>3`GH28G-B<E),<6)PD4QZ$V)W4Z-
MA`:AZ]EN3(G>2<'M&TC!Y@5,">Y,BZPD0`$``$:--`9-B>!)P>P"2<'@'DT)
MX$P)P$2)QDF)Q$B)T$@A\$TAW$D)Q+C<O!N/20'%3`'I38GU20',3(GQ2<'M
M&TC!X05,">E)B?5!`<Q,B=E)P>L"2,'A'DP)V4&)RTD)R$TA\$TAW4T)Z$R+
MK"1(`0``20'%3`'J38GE20'03(GB2<'M&TC!X@5,">I&C2P"3(GR2<'N`DC!
MXAY,"?)-B=Y!B=!("=%-(<9,(>%,"?%,B[0D4`$``$D!QDP!]DV)[D@!\4R)
M[DG![AM(P>8%3`GV1(TT#DR)YDG![`)(P>8>3`GF38G$B?%("?))(<Q,(>I,
M">),BZ0D6`$``$D!Q$T!XTV)]$P!VDV)\TG!XP5)P>P;30GC18TD$TV)ZTG!
M[0))P>,>30GK28G-1(G:3`G>22'53"'V3`GN3(NL)&`!``!)`<5-`>A-B>5,
M`<9-B>!)P>T;2<'@!4T)Z$6-+#!-B?!)P>X"2<'@'DT)\$F)UD2)QDT)PTDA
M]DTAXTT)\TR+M"1H`0``20'&3`'Q38GN20'+3(GI2<'N&TC!X05,"?%&C309
M3(GA2<'L`DC!X1Y,">%)B?1!B<M)"<A-(>A-(=Q-">!,BZ0D<`$``$D!Q$P!
MXDV)]$D!T$R)\DG![!M(P>(%3`GB1HTD`DR)ZDG![0)(P>(>3`GJ38G=08G0
M2`G132'%3"'Q3`GI3(NL)'@!``!)`<5,`>Y-B>5(`?%,B>9)P>T;2,'F!4P)
M[D2-+`Y,B?9)P>X"2,'F'DP)]DV)QHGQ2`GR22'.3"'B3`GR3(NT)(`!``!)
M`<9-`?--B>Y,`=I-B>M)P>,%2<'N&TT)\T6--!--B>-)P>P"2<'C'DT)XTF)
MS$2)VDP)WDDAU$PA[DP)YDR+I"2(`0``20'$30'@38GT3`'&38GP2<'L&TG!
MX`5-">!%C20P38GH2<'M`DG!X!Y-">A)B=5$B<9-"<-)(?5-(?--">M,BZPD
MD`$``$D!Q4P!Z4V)Y4D!RTR)X4G![1M(P>$%3`GI1HTL&4R)\4G![@)(P>$>
M3`GQ28GV20G(08G+32'>32'@30GP3(NT))@!``!)`<9,`?)-B>Y)`=!,B>I)
MP>X;2,'B!4P)\D:--`),B>))P>P"2,'B'DP)XDV)W$&)T$@)T4TAQ$PAZ4P)
MX4R+I"2@`0``20'$3`'F38GT2`'Q3(GV2<'L&TC!Y@5,">9$C20.3(GN2<'M
M`DC!YAY,">Y-B<6)\4@)\DDAS4PA\DP)ZDR+K"2H`0``20'%30'K38GE3`':
M38GC2<'M&TG!XP5-">M%C2P338GS2<'N`DG!XQY-"?-)B<Y$B=I,"=Y)(=9,
M(>9,"?9,B[0DL`$``$D!QDT!\$V)[DP!QDV)Z$G![AM)P>`%30GP18TT,$V)
MX$G![`))P>`>30G@28G41(G&30G#22'T32'K30GC3(ND)+@!``!)`<1,`>%-
MB?1)`<M,B?%)P>P;2,'A!4P)X4:-)!E,B>E)P>T"2,'A'DP)Z4F)]4&)RTD)
MR$TA\$TAW4T)Z$R+K"3``0``20'%3`'J38GE20'03(GB2<'M&TC!X@5,">I&
MC2P"3(GR2<'N`DC!XAY-B=A,"?)!B=9("=%-(?!,(>%,"<%,BX0DR`$``$D!
MP$P!QDV)Z$@!\4R)[DG!Z!M(P>8%3`G&1(T$#DR)YDG![`)(P>8>3(GQ3`GF
M08GT2`GR3"'A3"'J2`G*2(N,)-`!``!(`<%)`<M,B<%(`X0DV`$``$P!VDV)
MPTC!X05)P>L;3`G9B<E,`?!(`<I,B>E)P>T"2,'A'D&)TTP)Z4V)Y4&)ST@)
MSDTA_4PAQDP)[DV)W4@!\$R)WDG![1M(P>8%3`GNB?9(`?!,B<9)P>@"2,'F
M'D&)Q4D)\+[6P6+*3#'!,<I(BXPDX`$``$@!\4D!S$R)Z4P!XDV)[$C!X05)
MP>P;3`GAB<E(`<I,B=E(P>$>2<'K`D&)U$D)RTR)P4V)YDPQV4G![AM%B<`Q
MR$B+C"3H`0``2`'Q20'/2HT,.$R)X$C!X`5,"?")P$R--`%,B>A)P>T"2,'@
M'DR)V46)VTD)Q4B+A"3P`0``18GW3#'I,<I,B?E(`?!(P>D;3`'`2`'"3(GX
M2,'@!4@)R$B+C"3X`0``B<!(`<),B>!)P>P"2,'@'D@!\4&)T$P)X$P!V4V)
MZTDQPTV)Q$6)[44QWDG![!M.C1PQ3(G!2,'A!4P)X8G)20'+3(GY2<'O`DC!
MX1Y%B=Q)"<](BXPD``(``$@!\4P!Z4F)Q8G`33']1#'J3(TL$4R)XDR)X4C!
MZ1M(P>(%2`G*3(G!2<'H`HG22,'A'DD!U4B+E"0(`@``3`G!38GX18GN18G_
M23'(2`'R13'#2`'03(GR3HT$&$R)\$C!ZAM(P>`%2`G02(G*B<F)P$D!P$R)
MX$G![`)(P>`>18G#20G$2(N$)!`"``!,,>)!,=5,B=I(`?!,`?A)`<5,B=A(
MP>`%2,'J&T@)T$R)\DG![@*)P$C!XAY)`<5(BX0D&`(``$P)\D6)[T@!\$@!
MR$R)X46)Y$@QT4$QR$R)^4D!P$R)^$C!Z1M(P>`%2`G(B<!)`<!,B=A)P>L"
M2,'@'D6)QDD)PTB+A"0@`@``3(GQ2,'I&T@!\$P!X$F)U(G233'<13'E3HTD
M*$R)\$C!X`5("<A(BXPD*`(``(G`20'$3(GX2<'O`D@!\4C!X!Y%B>5,"?A(
M`<I,B=E(,<%%B=M!,<A,B>E)`=!,B>I(P>D;2,'B!4@)RHG220'03(GR2<'N
M`DC!XAY%B<=)"=9(BY0D,`(``$R)^4C!Z1M(`?),`=I)B<.)P$TQ\T4QW$Z-
M'"),B?I(P>(%2`G*3(GI2<'M`HG22,'A'DD!TTB+E"0X`@``3`GI18G<2`'R
M2`'03(GR18GV2#'*03'03(GB20'`3(G@2,'J&TC!X`5("=!(B<J)R8G`20'`
M3(GX2<'O`DC!X!Y%B<5)"<=(BX0D0`(``$@!\$PQ^DP!\$$QTTR)ZDD!PTR)
MZ$C!ZAM(P>`%2`G03(GB2<'L`HG`2,'B'DD!PTB+A"1(`@``3`GB18G>28G4
M2`'P2`'(3(GY18G_2#'1B=)!,<A*C0P`3(GP38GP2<'H&TC!X`5,"<")P$@!
MP4R)Z$G![0)(P>`>08G(20G%2(N$)%`"``!-,>Q%,>--B<1(`?!)P>P;3`'X
M20'#3(G`2,'@!4P)X(G`20'#3(GP2,'@'DG![@)%B=Q,"?!,B[0D6`(``$D!
M]DD!UDR)ZD6)[4@QPC'128T4#DR)X4V)YDG![AM(P>$%3`GQB<E(`<I,B<%)
MP>@"2,'A'D&)UDD)R$B+C"1@`@``2`'Q3`'I28G%B<!-,<5%,>M-B?5)`<M,
MB?%)P>T;2,'A!4P)Z8G)20'+3(GA2<'L`DC!X1Y%B=U)"<Q(BXPD:`(``$@!
M\4@!R$R)P46)P$PQX3'*2(T,$$R)Z$R)ZDC!ZAM(P>`%2`G03(GR2<'N`DC!
MXAZ)P$D)UDB+E"1P`@``2`'!B<A(`?),`<)-B>!-,?!%,<-)B<!,`=I)B<-)
MP>`%2<'K&TT)V$F)PTC!Z`))P>,>00'03(GJ20G#2(N$)'@"``!(P>(>2<'M
M`D$!VTD)U42)XDR)7Q!(`?!$`>U(`<),B?!(B6\83#'H,<%(C00*3(G"3(G!
M2,'B!4C!Z1M%`<A("<I,B4<(`=!!`<)$`W<@2(N$)(@"``!D2#,$)2@```!,
MB1=,B7<@=1)(@<28`@``6UU!7$%=05Y!7\/HXN/__V:005=!5D%505154TB#
M[`A(A?\/A+$```!,BSVJ>"``387_#X2A````#[8'A,!T!#P]=5Y%,>1)BQ](
MA=MT.4F)]4F)_DUCY$R)_0\?@`````!,B>),B?9(B=_HPN+__X7`=0="@#PC
M/71'2(/%"$B+70!(A=MUVDB#Q`A(B=A;74%<05U!7D%?PP\?A```````28G\
M28/$`4$/M@0DA,!T!#P]=>]!*?SKC`\?@`````!,*?U*C5PC`4C!_0-!B6T`
MZ[1F#Q]$```QV^NJ#Q]``%532(G]2(/L&&1(BP0E*````$B)1"0(,<!(C5PD
M!&:0,<!(B=Y(B>_H`____TB%P'0V2&-4)`1(BP6Z=R``2(T$T$B+4`A(A=)(
MB1!TTF:02(/`"$B+4`A(A=)(B1!U\.N^9@\?1```2(M$)`AD2#,$)2@```!U
M!TB#Q!A;7</HC.+__V:09BX/'X0``````$%7059!54%455-(B?-(B?U(@^PH
M9$B+!"4H````2(E$)!@QP#'`@#X]#Y3`2`'#2(G?Z#GB__](C70D%$F)Q$B)
M[S'`Z%?^__](A<`/A`X!``!(B<=)B<7H$^+__TPYX`^#X@```$QC="042<'F
M`P^V10"$P`^$K0$``#P]#X2E`0``2(GHZPT/'X0``````(#Z/70+2(/``0^V
M$(32=?!(*>A(F$P#-;QV(`!*C7P@`NCZXO__2(7`28D&#X1[`0``2&-4)!1(
MBP6:=B``2(U-`4B+%-`/MD4`/#V(`G0FA,!U$.L@9BX/'X0``````#P]=!)(
M@\$!#[9!_TB#P@&$P(@"=>K&`CTQP`\?1```#[8,`XA,`@%(@\`!A,EU\#'`
M2(MT)!AD2#,T)2@````/A1$!``!(@\0H6UU!7$%=05Y!7\,/'P!(@\,!#[9#
M_TF#Q0&$P$&(1?]U[.O"9I!,BST!=B``28,_``^$OP```$R)^#'2ZPL/'X0`
M`````$2)ZDB#P`A$C6H!2(,X`'7OC7(#2&/V2,'F`XL%_X4@`(7`=5M(B??'
M!>Z%(``!````Z/GA__](A<`/A'T```!-8\5,B?Y(B<=.C33%`````$R)1"0(
M3(GRZ(+B__],BT0D"$B)P4B)!7MU(`!*QT3!"`````!$B6PD%.EO_O__3(G_
MZ#CB__](A<!(B<%(B053=2``="9-8\5.C33%`````.O)#Q]``#'`Z7;^__^0
MOA````!%,>WI7O___[C_____Z=O^___H-.#__P\?0`!!5T%6055!5%532('L
MN````&1(BP0E*````$B)A"2H````,<!(A?]T"(`_`$F)_G4O2(N$)*@```!D
M2#,$)2@````/A20!``!(@<2X````6UU!7$%=05Y!7\-F#Q]$``#H:]___TB%
MP$B)PW3$2(U$)!!(C2W<&P``3(TEU!L``$R-/=`;``!(B00D2(G?Z(WA__](
MA<`/A+0```!,C4@3N0(```!(B>],B<[SIG3<N0,```!,B<Y,B>?SIG3-3(GW
M3(E,)`CH5=___TR+3"0(28G%3(G/Z$7?__]!C7P%`DAC_^AXX/__3(M,)`A)
MB<5(B<=-B?!,B?E(Q\+_____O@$````QP.C4X?__2(L4)+\!````3(GNZ*/>
M__^#^/],B>]T$(M$)"@E`/```#T`0```=##H)M[__TR)[^C^W?__Z43___]F
M#Q^$``````!(B=_H6-___TR)]^BPWO__Z<S^___HEO[__^O.Z+_>__\/'T0`
M`&8N#Q^$``````!32(G[BSUF<R``Z,'?__](C9```@``2(G>OP$```#HW>#_
M_X7`=`DQP%O##Q]$``"+/3IS(`#HE=___XN`&`(``"4`\```/0!```!T'8L]
M'7,@`.AXW___BX`8`@``)0#P```]`*```'6]2(G?O@(```#H2>#__X7`#Y3`
M#[;`6\,/'T0``&8N#Q^$``````!!5D%528GV051528G\4TB-/3@:``"Z_P\`
M`$B![!`0``!(B>-(B=YD2(L$)2@```!(B80D"!```#'`Z$'=__^%P`^.B0``
M`(U0_T2++8]R(`!(8^J`/"P`=%9(8^A(B>J^+P```$B)W^ACWO__2(7`=$9$
MB>_HQM[__TB)Z4B)VDR)YDB)Q^C%W___2(N$)`@0``!D2#,$)2@```!U.TB!
MQ!`0``!;74%<05U!7L-FD(72=:D/'T``1(GOZ(#>__],B?),B>9(B<?HDMW_
M_^N[1(LM"7(@`.O?Z$+=__]FD$B#[`B+/?9Q(`#H4=[__TB+%8IQ(`!(C0U+
M&P``2(TU6!D``$B)QTB#Q`CI<-[__TB#[`B+/<9Q(`#H(=[__TB)Q^BY____
MBSVS<2``Z`[>__],C06X&@``2(T5$!0``$B--3$9``!%,<E(B<=(@\0(3(G!
MZ7?>__\/'X``````55-(@>PH(```9$B+!"4H````2(F$)!@@```QP$B)XTB-
MK"00$```Z!3<__],C0W%&```2(T-\Q@``$&)P+H!$```O@$```!(B=\QP.@?
MW___N@`0``!(B>Y(B=_HO]O__X7`>%.->`%(B<-(8__H?=W__TB%P$B)P708
M2&/;2(GN2(G'2(G:Z#3=__](B<'&!!@`2(N4)!@@``!D2#,4)2@```!(B<AU
M$TB!Q"@@``!;7<,/'T0``#')Z]?H_]O__P\?1```9BX/'X0``````.DK____
MD&8N#Q^$``````!!5T%6055!5$F)]%532(G[2(T]0A@``$B!["@0``!D2(L$
M)2@```!(B80D&!```#'`2(UT)`SHQ??__[XO````2(G?2(G%Z+7;__](A<!T
M0$B-/0L8``!(B=XQP.C_^/__2(G82(N,)!@0``!D2#,,)2@````/A9H!``!(
M@<0H$```6UU!7$%=05Y!7\,/'P!(B=_H.-O__TB--=`7``!,B>=!B<7H5MW_
M_TB%P$F)QW2>08/%`4&`/P!,C60D$$R--:L7```/A.(````/'T``2(7M=!-,
MB?Y(B>_HT-O__X7`#X2B````3(G_Z.#:__^)PDB808!\!_\O=1</'T``@^H!
M2&/"08!\!_\O0<8$!P!T[40!ZH'Z_P\```^/+O___TB#[`A(C0TZ&```38GQ
M4TV)^+H`$```O@$```!,B><QP.A(W?__BSU2;R``Z*W;__](C9```@``3(GF
MOP$```#H"=K__X7`6EEU'8L]+6\@`.B(V___BX`8`@``)0#P```]`(```'1>
M2(TUWA8``#'_Z&C<__](A<!)B<</A*S^__]!@#\`#X4B____2(7M=!U(C3U+
M%@``N0(```!(B>[SIG3$9BX/'X0``````$R-/2X6``"Z`0```.DR____#Q^`
M`````+X!````3(GGZ/O;__^%P'612(T]8A8``$R)YNA8]___3(GGZ&#<___I
M3_[__^C&V?__9@\?1```#[872(GXA-)T'F8/'T0``$B#QP&`^B\/MA=(#T3'
MA-)U[O/##Q]``//#9@\?1```2(7_#X3/````55-(@^P(#[8O0(3M="E(B?OH
M8=G__TB-5`/_2#G3<A#K.P\?1```2(/J`4@YTW0W@#HO=/+K'4B#Q`A(C3UJ
M%0``6UWISMO__V8/'T0``(`Z+W0X2(/J`4@YTW+R2#G3=2H/'T0``$"`_2]T
MRDB#Q`A(C3V@%0``6UWIF-O__P\?A```````@#HO=0E(@^H!2#G3<O)(*=I(
MC4("2#T`$```=SM(C3W\;2``2(/"`;D`$```2(G>Z%O:__](C07D;2``2(/$
M"%M=PP\?1```2(T]UA0``.D\V___#Q]``#'`Z^`/'T``4TB-/2L5``!(@^Q`
M9$B+!"4H````2(E$)#@QP`^W!9T6``!(C5PD#/,/;P5P%@``#RE$)!!FB40D
M,#'`\P]O!6P6```/*40D(.A"]?__2(T]YQ0``#'`Z#3U__](C3WA%```,<#H
M)O7__TB-/=P4```QP.@8]?__2(T]U10``#'`Z`KU__](C3W7%```,<#H_/3_
M_TB-/7X4```QP.CN]/__2(T]QQ0``#'`Z.#T__](C3W#%```,<#HTO3__TB-
M/;\4```QP.C$]/__2(T]3Q0``#'`Z+;T__](C3VM%```,<!(B=[HU?/__TB%
MP'012(T]@Q0``$B)QC'`Z!_U__](C3V7%```,<!(B=[HKO/__TB%P'012(T]
MDQ0``$B)QC'`Z/CT__](C3V-%```,<!(B=[HA_/__TB%P'1"2(T]U!,``$B)
MQC'`Z-'T__](C362%```2(T]]Q,``#'`Z+ST__](BT0D.&1(,P0E*````'5B
M2(/$0%O#9@\?1```2(T]110``#'`2(G>Z"_S__](A<!U*DB-="0A2(T].Q0`
M`+D*````\Z9UI$B-="0K2(T]N1,``#'`Z&+T___KCTB-/:D3``!(B<8QP.A/
M]/__Z7G____HQ=;__P\?1```2(/L&&1(BP0E*````$B)1"0(,<"+!59K(`"#
M^/]T&4B+?"0(9$@S/"4H````=4!(@\08PP\?0`!(C70D!$B-/4P3```QP.B5
M\O__2(G",<!(A=)T$@^V$H#Z,`^5P3'`A-(/E<`AR(D%`VL@`.NPZ$S6__]F
MD&8N#Q^$``````!(@^P(Z$?6__^)Q^CPU?__2(7`=`M(BP!(@\0(PP\?`#'`
MZ_1FD&8N#Q^$``````!!5%5(B?U32(T]3!,``$B#[!!D2(L$)2@```!(B40D
M"#'`2(UT)`3H!/+__TB%P$B)[G1\@#@`2(G#='1(B<?H;-C__TB%P'5U2(GO
MZ*_5__](B=])B<3HI-7__TF-?`0"Z-K6__](@^P(3(T-+A(``$B-#1\3``!3
M2,?"_____TB)QTF)Q$F)Z+X!````,<#H*]C__TB-/;X2``!,B>8QP.CJ\O__
M6%KK%&8/'T0``$B-/:,2```QP.C2\O__2(M$)`AD2#,$)2@```!U"4B#Q!!;
M74%<P^@TU?__#Q]``$%7059!54%428G]55-(C3V5$0``2('LB($``&1(BP0E
M*````$B)A"1X@0``,<!(C05A$@``3(UD)"Q(QT0D0`````!(QX0DF```````
M``!(QT0D8`````!(B40D,$B-!?$0``!,B>9(B40D.$B-!<X1``!(B40D<$B-
M!;L1``!(B40D>$B-!1`2``!(B80D@````$B-!;T1``!(B80DB````$B-!?H1
M``!(B80DD````$B-!=(1``!(B40D4$B-!>,1``!(B40D6#'`Z(#P__](A<!T
M"8`X``^%4@(``#'`Z`O^__](A<!(B<,/A(\"``!(B=_H)]3__TB-?``!Z%W5
M__^`.P!)B<9T-TR-/9X1``!,B?4/'P!$#[8#2(GO,<!,B?E(Q\+_____O@$`
M``!(@\,!2(/%`NBCUO__@#L`==9(C5PD<$B-/?,0``#K$$B#PPA(BSM(A?\/
MA'@!```QP$R)YNCF[___2(7`2(G%=-Z`.`!TV4B)Q^@!]?__A<!TS4B)[^@U
MUO__2(7`28G'#X1!`0``9@\?A```````3(GZBPI(@\($C8'__O[^]]$AR"6`
M@("`=.F)P<'I$*F`@```#T3!2(U*`D@/1-&)P0#!3(GQ2(/:`TPI^HLQ2(/!
M!(V&__[^_O?6(?`E@("`@'3IB<;![A"I@(````]$QDB-<0)(#T3.B<9``,9(
M@]D#3"GQC9P*!`0``$ACVTB)W^@YU/__2(G%2(T%C1```$%63(T-AP\``$B-
M#700``!-B?A02,?"_____[X!````2(GO,<#HA=7__[[``0``2(GOZ!C2__^#
M^/]!6$%9=1+HVM'__T2+"$&#^1$/A=,(``"+/6=G(`#HPM/__TB-D``"``!(
MB>Z_`0```.C>U/__A<!!B<</A$,!``!)BTT`2(L]>&<@`$B-%>D0``!)B>B^
M`0```#'`,=OHX-3__^M^9@\?1```,>UF#Q]$``!(8\5(BUS$,$B%VW0[@#L`
M=#9(B=^#Q0'H@_/__X7`=-](B=_HM]3__TB%P$F)QP^%B_[__TACQ4B+7,0P
M2(7;=<MF#Q]$``!%,?_I</[__TB)QTB)!"3HY/O__TB+!"1(B<?H>-3__TB)
MPP\?1```2(N,)'B!``!D2#,,)2@```!(B=@/A>4(``!(@<2(@0``6UU!7$%=
M05Y!7\,/'T``2(T]`P\``#'M2(7_="9FD#'`3(GF@\4!Z+/M__](A<!T!8`X
M`'4I2&/%2(M\Q%!(A?]UW+\-````2(T=SPX``.B;TO__28G&Z3[]__\/'P!(
MB<?HZ-/__TB%P$B)PP^%#?W__^O!9BX/'X0``````(L]^F4@`.A5TO__BX`8
M`@``)0#P```]`$````^%G/[__XL]V64@`.@TTO__1(NP'`(``.@8T?__03G&
M#X5\_O__BSVY92``Z!32__^+@!@"```E_P$``#W``0``#X5;_O__2(G?Z`;2
M__](C3TD#@``2(G#3(GF,<#HXNS__TB%P`^$:0$``$B)Q^A!T___28M]`$B)
MQNC%]/__2(7`28G$#X1)`0``3(GGZ('0__^#^`-^/$ACT$B-/14.``"Y!0``
M`$F-=!3\\Z9U)(/X!`^$"P8``(/H!$B808!\!/\O#X3Z!0``9BX/'X0`````
M`#'`Z(GY__^%P'45,?9,B>?H"]+__X7`08G&#X7P````2(TU<0T``$B-/?(,
M``!,C27L#0``,<!,C2VC#```Z(WM___HB,___T%43(T-D`P``%!(C0VC#0``
M2,?"_____TF)Z+X!````2(G?,<#HCM+__UA:ZTUF+@\?A```````Z.O.__^#
M.!%U2^A!S___08/'`4B#[`A(C0UL#0``051!5TV)Z5!)B>A(Q\+_____O@$`
M``!(B=\QP.A!TO__2(/$(+[``0``2(G?Z-#.__^#^/]TJTB)[^B#SO__2(T]
MY0L``$B)WC'`Z.+L__](B=_H2OG__^EU_?__#Q]$``!-BV4`Z:[^__\/'X``
M````N@(```!(Q\;N____B<?HG='__TB-A"1P`0``N@8```!$B?=(B<9(B00D
MZ-'/__^`O"1P`0```'4.@+PD<0$``$,/A(D%```QTC'V1(GWZ%W1__^XB:O-
M[TR-K"2@````2,>$)*`````!(T5G2(F$)*@```!(+8O.$E=(QX0DN````'94
M,A!(B80DL````$@%\@08*TC'A"3(`````````$B)A"3`````28U%.$C'A"30
M`````````,>$)!@!````````2(E$)`@/'X0``````$B+-"2Z`(```$2)]^@?
MS___A<!)B<1!B<`/CG$!``!(B[PDR````$ECQ$B+E"30````C33'2#G^2(FT
M),@```!(@](`2,'H'4@!T$B)A"30````2&.$)!@!``"%P`^$'0$``$B+3"0(
M0;A`````2(LT)$$IP$4YQ$4/3L1(C3P!26/028G72(E4)!#HX,[__XN$)!@!
M``!$`?B#^$")A"08`0``#X56____18G@3(GO12GX3(M\)!!,`SPD1(E$)!SH
MNM/__T2+1"0<#Q]$``!!@_@_?GE!C4#`B40D','H!D&)Q(E$)!!)@\0!2<'D
M!DT!_`\?1```\T$/;P=,B>])@\=`#Q&$)-@```#S00]O1]`/$80DZ````/-!
M#V]'X`\1A"3X````\T$/;T?P#Q&$)`@!``#H1=/__TTY_'6XBT0D$$2+1"0<
MP>`&02G`2(M\)`A)8]"Y2````$R)_D2)1"00Z/?-__]$BT0D$$2)A"08`0``
MZ87^__\/'T0``$R+/"3I1____P\?@`````!$B??H2,W__TR+I"3(````3(NT
M)-````!,B>!(P>@#@^`_C5`!2)C&A`38````@(/Z.`^/@P(``+@X````,?8I
MT$ACTH/X"$F-5!4X#X/<`@``J`0/A88#``"%P'0+J`+&`@`/A8H#``!,B?!,
MB>]$B+0D$P$``$C!Z!A$B*0D%P$``$R-K"1``0``B(0D$`$``$R)\$C!Z!"(
MA"01`0``3(GP3(TUM@D``$C!Z`B(A"02`0``3(G@2,'H&(B$)!0!``!,B>!(
MP>@0B(0D%0$``$R)X$4QY$C!Z`B(A"06`0``Z`G2__](BX0DH````$B)PHB$
M)",!``!(P>H81`^VPHB4)"`!``!(B<)(P>H0B)0D(0$``$B)PDB+A"2H````
M2,'J"(B4)"(!``!(B<*(A"0G`0``2,'J&(B4)"0!``!(B<)(P>H0B)0D)0$`
M`$B)PDB+A"2P````2,'J"(B4)"8!``!(B<*(A"0K`0``2,'J&(B4)"@!``!(
MB<)(P>H0B)0D*0$``$B)PDB+A"2X````2,'J"(B4)"H!``!(B<*(A"0O`0``
M2,'J&(B4)"P!``!(B<)(P>H0B)0D+0$``$B)PDB+A"3`````2,'J"(B4)"X!
M``!(B<*(A"0S`0``2,'J&(B4)#`!``!(B<)(P>H0B)0D,0$``$B)PDC!Z@B(
ME"0R`0``Z0P````/'P!&#[:$)"`!``!+C7QE`#'`3(GQ2,?"_____[X!````
M28/$`>A8S?__28/\%'722(T%;`@``,:$)&@!````4$%52(T-)@@``$R-#1,'
M``"^`0```$F)Z$C'PO____](B=\QP.@9S?__65[IY_K__V:038MM"$V%[0^$
M`_K__TR)[^@[RO__2(/X`P^&\?G__TF-=`7\2(T]S0<``+D%````\Z9-#T3E
MZ=7Y__^X0````$ACRBG028U,#3AT#S'2B=:#P@$YPL8$,0!R\TR)[^@-T/__
M9@_OP`\1A"38````2<=%:`````!!#Q%%2$$/$458Z6/]__])BTT`2(L]SUX@
M`$B-%0`(``!)B>B^`0```#'`,=OH-\S__^G2]___B<%(QP(`````2,=$"O@`
M````2(U*"$B#X?A(*<H!T(/@^(/X"`^"$/W__X/@^#'2B=>#P@@YPDB)-#ER
M\^GY_/__@+PD<@$``$$/A6GZ__^`O"1S`0``0P^%6_K__X"\)'0!``!(#X5-
M^O__@+PD=0$``$4/A3_Z__^Z`@```$C'QL;___]$B??HE,O__TR+/"2Z*0``
M`$2)]TR)_NC0R?__2(T%V@8``%!!5^EQ_O__D,<"`````,=$`OP`````Z7;\
M__\Q_V:)?`+^Z6K\___HW,C__V:09BX/'X0``````$%7059!54%455-(@^P8
MBSU\72``9$B+!"4H````2(E$)`@QP$R-;"0$Z,+)__^+/5Q=(`!(B</HM,G_
M_P^VD[@```!(C3TZ!0``3(GNB)"Y````,<#HEN3__TB%P'0)@#@Q#X0(`P``
M,<#HP>___XL]&UT@`.AVR?__2(TU&@8``+D+````N@$```!(B<?H'<G__TB%
MP`^$Q````(,]76T@``%(BT`01(LUXEP@`$R+8"@/CJ\````Q[;L!````ZSH/
M'X``````28MW$$B+!25M(`!(8]-(BSS0Z,'(__^%P(L5&6T@``^%"`(``(/#
M`8/%`3G3#XWZ`0``1(GWZ.W(__\QR4ACU4R)YDB)Q^B]R?__2(7`#X3,`0``
M3(LX1(LU:EP@`$&+1PPE``0@`#T`!```=))$B??HLLC__TR)_KD"````,=)(
MB<?HT,?__T2+-3E<(`!(B<;I;?___Y!$BS4I7"``1(GWZ('(__](C34J!0``
MN0,```"Z`0```$B)Q^@HR/__2(7`2(G#=#5(BT`0BSWV6R``2(LHZ$[(__](
MC17Y!```2(G'2(GNZ%S'__](BT,02(L8]D,.0`^%ZP$``(L]Q5L@`.@@R/__
M2(TUT`0``+D#````N@$```!(B<?HQ\?__TB%P$B)PW0]2(T]6@,``#'`3(GN
MZ.[B__](A<!(B<4/A'(!``!(BT,0BSUX6R``2(L8Z-#'__](B>I(B<=(B=[H
MXL;__XL]7%L@`.BWQ___2(TU:00``+H!````2(G'Z,/'__^+/3U;(`!(B</H
ME<?__TB-%5P$``!(B=Y(B<?HH\;__XL]'5L@`.AXQ___2(T]R@(``,:`N0``
M``!,B>XQP.A@XO__2(7`2(G#2(D%:VL@``^$G0```+[``0``2(G?Z'#%__^-
M4`&#^@%V"8/X$0^%#P$``$B+1"0(9$@S!"4H````#X7V````2(/$&%M=05Q!
M74%>05_##Q]``(L5$FL@`$2+-9M:(`"-0O\YZ`^%9_[__X/Z`0^.7O[__[L!
M````9I!$B?>#PP'HU<;__TR)YDB)Q^@:Q?__.1W4:B``1(LU75H@`'_;Z2W^
M__]F#Q]$``!(BSVQ:B``Z%3P__](A<!(B<-(B06O:B``#X5$____2(T].@0`
M`#'`Z+/&__\/'P"`>`$`#X3U_/__Z>G\__^02(L%<6H@`(L]`UH@`$B+*$B+
M0Q!(BQCH5,;__TB)[DB)W^@)Y___Z8+^__\/'T``BSW:62``Z#7&__](B=Y(
MB<?HBL;__^GZ_?__Z`#%__^)P4B+!1]J(`!(C3WH`P``2(G:2(LP,<#H,\;_
M_P\?`%532(G]2(/L".A"Z___#[802(G#A-)T&@\?A```````2(/``8#Z+P^V
M$$@/1-B$TG7N,<#HY^W__TB%[70=A<!T&8!]``!T$TB-/1\"``"Y!````$B)
MWO.F=`=(@\0(6UW#2(/$"$B)[UM=Z4#D__](BPT162``Z?3$__\/'T``05=!
M5DF)UT%5051,C25^5"``54B-+7Y4(`!308G]28GV3"GE2(/L"$C!_0/H#\/_
M_TB%[70@,=L/'X0``````$R)^DR)]D2)[T'_%-Q(@\,!2#G==>I(@\0(6UU!
M7$%=05Y!7\.09BX/'X0``````//#``!(@^P(2(/$",,````!``(`+BX`)7,O
M)7,`+W!R;V,O<V5L9B]E>&4`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R
M`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`"]P<F]C+R5I+R5S`%!!4E]414U0`%!!
M4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)0@!015),-4]05`!015),
M24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?
M1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]4
M35!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#
M3$5!3@!005)?0TQ%04X]`#$`3$1?3$E"4D%265]0051(`%5315(`4UE35$5-
M`"]T;7``5$5-4$1)4@!435``55-%4DY!344`)3`R>``E<R5S)7,E<P!P87(M
M`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S=&5M<"TE=25S`"5S)7-T
M96UP+25U+25U)7,`05)'5@`8`'!E<FP`,`!005(Z.E!A8VME<CHZ5D524TE/
M3@`Q+C`T,P`M90`M+0````````!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@
M("`@("`@(```````````<&5R;'AS:2YC`````````"5S.B!C<F5A=&EO;B!O
M9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`
M```````E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP
M;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````
M````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``````````"5S
M.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F
M86EL960@*&5R<FYO/25I*0H``````````&5V86P@)V5X96,@+W5S<B]B:6XO
M<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N
M9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1P87)?=&5M
M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#
M3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A
M<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE
M.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V
M:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D
M97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E
M;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/
M(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%
M35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ
M9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^
M(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X
M("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G
M)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<
M)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC
M:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL
M96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES
M=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S
M('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]
M('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@
M)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I
M.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@
M*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG
M*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W
M:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O
M7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I
M.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I
M.PI["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@
M)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F
M.PIM>2`D<VEZ92`]("US("1P<F]G;F%M93L*;7D@)&]F9G-E="`](#4Q,CL*
M;7D@)&ED>"`]("TQ.PIW:&EL92`H,2D*>PHD;V9F<V5T(#T@)'-I>F4@:68@
M)&]F9G-E="`^("1S:7IE.PIS965K(%]&2"P@+21O9F9S970L(#(@;W(@9&EE
M('%Q6W-E96L@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T["FUY("1N<F5A
M9"`](')E860@7T9(+"`D8G5F+"`D;V9F<V5T.PID:64@<7%;<F5A9"!F86EL
M960@;VX@(B1P<F]G;F%M92(Z("0A72!U;FQE<W,@)&YR96%D(#T]("1O9F9S
M970["B1I9'@@/2!R:6YD97@H)&)U9BP@(EQN4$%2+G!M7&XB*3L*;&%S="!I
M9B`D:61X(#X](#`@?'P@)&]F9G-E="`]/2`D<VEZ92!\?"`D;V9F<V5T(#X@
M,3(X("H@,3`R-#L*)&]F9G-E="`J/2`R.PI]"FQA<W0@=6YL97-S("1I9'@@
M/CT@,#L*)&]F9G-E="`M/2`D:61X("T@-#L*<V5E:R!?1D@L("TD;V9F<V5T
M+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L("TD;V9F<V5T("T@
M=6YP86-K*").(BP@)&)U9BDL(#(["G)E860@7T9(+"`D8G5F+"`T.PHD9&%T
M85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*;7D@)7)E<75I<F5?;&ES=#L*=VAI
M;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D
M(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]
M("1B=68["F]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI
M*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\
M?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U
M9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F
M:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI
M('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B=68L
M(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D
M9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]
M("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB
M+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M
M92`](%]T96UP9FEL92@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO
M=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?
M;&ES='LD9G5L;&YA;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F
M=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]
M/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@
M0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R
M;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&9I;&5N86UE(#T@
M9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PIM>2`D:V5Y
M.PIF;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*;F5X="!U;FQE<W,@
M+UQ1)&UO9'5L95Q%)"\["B1K97D@/2`D7SL@;&%S=#L*?0ID96QE=&4@)')E
M<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PI](&]R(')E='5R
M;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE
M(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z
M.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I
M92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F
M?3L*<V5E:R@D9F@L(#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D
M9FEL96YA;64@/2!?=&5M<&9I;&4H(B1F:6QE;F%M92T^>V-R8WTN<&TB+"`D
M9FEL96YA;64M/GMB=69]*3L*;W!E;B!M>2`D9F@L("<\)RP@)&9I;&5N86UE
M(&]R(&1I92`B8V%N)W0@<F5A9"`D9FEL96YA;64Z("0A(CL*8FEN;6]D92@D
M9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z
M(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!8
M4TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE
M879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@
M)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU
M;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!
M3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@
M)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE
M;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B
M4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0IM
M>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H
M95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I
M>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`]
M(#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R
M("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY
M("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?
M<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y
M7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@
M>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!
M4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D
M7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-
M3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*
M<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE
M=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`
M<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R
M.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE
M;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H
M)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@
M>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O
M<&5N(&QO9SH@)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA
M;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?
M8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H
M*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@
M=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!
M4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]
M"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H
M:79E.CI::7`["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*
M:68@*&1E9FEN960@)'!A<BD@>PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@Q,C@J,3`R-"D["F]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#
M86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D
M9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@
M)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@
M)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]
M("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI>
M<&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@
M("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD
M969I;F5D("1P87(I('L*;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A
M.B`D<&%R(CL*8FEN;6]D92A005(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2
M(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E
M4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/
M.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/
M.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E
M*"1F:"D["B0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@
M.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@
M/%]&2#X["FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^
M("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13
M=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A
M9&5R+"`D,"D*?0IF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2![
M"FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V
M86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%2
M7R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D
M:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA
M9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T
M*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F.PII
M9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U
M;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D
M8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA
M<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E
M>'!]*3L*?2!`24Y#.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y
M;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@
M)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["FUY("5W<FET
M=&5N.PIF;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D;F%M92P@
M)&9I;&4I.PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1N86UE(#T@
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*)&9I;&4@/2`D7SL*;&%S
M=#L*?0IE;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B@D
M9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["FQA<W0["GT*96QS:68@*&TA7B]L
M;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["FEF("AM>2`D<F5F(#T@)%!!
M4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]
M("@D<F5F+"`D,2D["FQA<W0["GT*96QS:68@*"UF("(D9&ER+R0Q(BD@>PHH
M)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*
M;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N
M86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<
M421L:6)?97AT7$4D+SL*;W5T<R@@:F]I;B`B(BP*<7$H4&%C:VEN9R`B*2P@
M<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`IQ<2@B+BXN*0HI
M.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D
M9FEL92T^>V)U9GT["GT*96QS92!["F]P96X@1DE,12P@)SPG+"`D9FEL92!O
M<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*8FEN;6]D92A&24Q%*3L*
M)&-O;G1E;G0@/2`\1DE,13X["F-L;W-E($9)3$4["E!!4CHZ1FEL=&5R.CI0
M;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0II9B`A)$5.
M5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD
M+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C
M;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"F]U=',H<7$H5W)I='1E;B!A<R`B
M)&YA;64B*2D["B1F:"T^<')I;G0H(D9)3$4B*3L*)&9H+3YP<FEN="AP86-K
M*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*)&9H+3YP<FEN="AS<')I;G1F
M*`HB)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT
M96YT*2P@)&YA;64**2D["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D
M8V]N=&5N="DI*3L*)&9H+3YP<FEN="@D8V]N=&5N="D["GT*?0HD>FEP+3YW
M<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["B1C86-H95]N86UE(#T@
M<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A
M;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["FUY("1C='@@/2!E
M=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q
M*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI3
M2$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG
M97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I
M9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E
M<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA
M9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T
M>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["F)I;FUO9&4H)&9H*3L*
M)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)&-A8VAE7VYA
M;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PI]"B1C86-H
M95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD
M8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N86UE
M*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L
M;V%D97(I*2D["B1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*)&9H+3YC;&]S
M93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E
M9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!
M4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@
M1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'II<"`]
M($%R8VAI=F4Z.EII<"T^;F5W.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PHD
M9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"([
M"B1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@
M07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*<'5S:"!`
M4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE
M?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U=',H<7$H
M7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI
M<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I
M('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N
M86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?
M;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S
M:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=
M*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE
M(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A
M8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E
M<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M
M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T
M7VYA;64B*2D["GT@96QS92!["F]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E
M<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O
M1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE
M*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB
M0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*
M57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@
M72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/
M;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G
M;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*
M;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H
M)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL
M97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*
M1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C
M(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S
M('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I
M;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q
M=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD[
M"G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U
M:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E
M;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q
M=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ
M1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E
M.CI::7`["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I
M<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T
M=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER
M92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A
M;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R
M97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U
M:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@
M<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N
M*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D
M<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!4
M14U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2![
M"FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M
M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U
M:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I
M;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R
M.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R
M;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T52
M3D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@
M/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L
M:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP
M9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE
M(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N
M("1P<F]G;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M
M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L
M("TU."P@,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O
M+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U
M9CL*?0IE;'-E('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@
M1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R
M97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S
M:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\
M?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I
M;VX@97$@)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I
M(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H
M+"`B/"1P<F]G;F%M92(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL
M92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)'-T;7!D:7(@+CT@(B1#;VYF:6=[
M7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D
M;71I;64@*3L*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!
M3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"([
M"GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-
M4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F
M:6QE('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D
M9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L
M;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@
M;7D@)&9H+"`G/B<L("1T96UP;F%M92!O<B!D:64@(F-A;B=T('=R:71E("1T
M96UP;F%M93H@)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@)&9H("1C;VYT96YT
M<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN
M960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL
M:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E
M=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A
M;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@
M/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@
M86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*
M)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M
M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/
M1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^
M/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T
M=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X
M97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*
M?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]
M7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%
M35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D
M0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@
M+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5]
M(CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\
M/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#
M;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ
M9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'
M971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D
M*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<
M12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]
M("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM0
M05)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD
M14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@
M5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I
M("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)
M4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.
M5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!
M3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?
M("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T
M92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?
M1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A
M;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D
M,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U
M=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L
M;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I
M;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F
M:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP
M('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H
M97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!0
M05(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R
M="A`<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@
M<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y
M7&XI"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ
M97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE
M("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ
M97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<
M*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?
M"@```````1L#.^P````<````B(/__S@!``!(A___8`$``%B'__]$!@``B(G_
M_P@!``"8BO__>`$``*B@___(`0``>*'__Q0"```(HO__0`(``%BD__^,`@``
MV*7__]@"``!HIO__^`(``$BG__\\`P``>*?__U0#``#(I___;`,``)BH__^8
M`P``J*C__ZP#``#(JO__#`0``/BJ__\@!```Z*O__W`$``#(K?__E`0``$BN
M__^P!```>*[__\P$``!8K___#`4``+B[___$!0``J+___Q`&```8P/__<`8`
M`"C`__^(!@``F,#__]`&````````%``````````!>E(``7@0`1L,!PB0`0<0
M%````!P```!XB/__*P``````````````%``````````!>E(``7@0`1L,!PB0
M`0``)````!P```!(@O__P`,````.$$8.&$H/"W<(@``_&CLJ,R0B`````!0`
M``!$````X(7__P@``````````````$P```!<````&(G__PX6````0@X0CP)"
M#AB.`T8.((T$0@XHC`5$#C"&!D$..(,'1P[0!0/F%0H..$$.,$$.*$(.($(.
M&$(.$$(."$$+````2````*P```#8GO__S`````!"#A"/`D(.&(X#0@X@C01"
M#BB,!4$.,(8&00XX@P=$#D`";`H..$0.,$$.*$(.($(.&$(.$$(."$D+`"@`
M``#X````7)___X0`````00X0A@)!#AB#`T<.,`)S"@X800X000X(00L`2```
M`"0!``#`G___3`(```!"#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&00XX@P=*
M#F`#)@$*#CA!#C!!#BA"#B!"#AA"#A!"#@A$"T@```!P`0``Q*'__W$!````
M0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'1P[P`7X*#CA!#C!!#BA"
M#B!"#AA"#A!"#@A'"P`<````O`$``/BB__^!`````$$.$(,":0H."$8+`E`.
M"$````#<`0``:*/__]X`````0@X0C@)"#AB-`T4.((P$00XHA@5$#C"#!E,.
MP"`"A`H.,$$.*$$.($(.&$(.$$(."$,+%````"`"```$I/__,`````!$#A!G
M#@@`%````#@"```<I/__20````!$#A!]#@@`*````%`"``!4I/__P0````!!
M#A"&`D$.&(,#1P[`0`*G"@X800X000X(1@L0````?`(``/BD__\%````````
M`%P```"0`@``]*3__QH"````0@X0CP)"#AB.`T(.((T$0@XHC`5$#C"&!D$.
M.(,'40[@(`)D"@XX00XP00XH0@X@0@X80@X00@X(1`L"E@[H($L.\"!Y#N@@
M00[@(````!````#P`@``M*;__RH`````````3`````0#``#0IO__[`````!*
M#A"&`D$.&(,#1`X@=0H.&$C##A!!Q@X(2PMB"@X82,,.$$'&#@A-"P)`#AA!
M#A!!#@A&P\90#B"#`X8"```@````5`,``'"G___;`0```$$.$(,"2PY0`VP!
M"@X000X(1PL8````>`,``"RI__]T`````$0.(&\*#@A%"P``&````)0#``"0
MJ?__)`````!$#A!8"@X(1`L``#P```"P`P``I*G__]P`````0@X0C`)!#AB&
M`T0.((,$2PXP`E@..$\.0&X..$$.,&H*#B!!#AA!#A!"#@A!"P"T````\`,`
M`$2J__]4#````$(.$(\"0@X8C@-"#B"-!$(.*(P%1`XPA@9!#CB#!TX.P(,"
M`Q@"#LB#`E(.T(,":`[(@P)"#L"#`@,"`0H..$$.,$$.*$(.($(.&$(.$$(.
M"$4+`ZH!#LB#`D@.T(,"80[(@P)!#L"#`F,.R(,"20[0@P)"#MB#`D0.X(,"
M70[`@P(#^P0.R(,"0@[0@P)H#LB#`D$.P(,"`U\!"@[(@P)"#M"#`D8+2```
M`*@$``#LM?__[0,```!"#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&00XX@P=$
M#E`#RP(*#CA!#C!!#BA"#B!"#AA"#A!"#@A%"S````#T!```D+G__W``````
M00X0A@)!#AB#`T<.(`)6"@X800X000X(00M$#AA$#A!!#@@H````*`4```R!
M__\M`@```$$.$(8"00X8@P-$#E`#O0$*#AA!#A!!#@A!"Q0```!4!0``H+G_
M_PP``````````````$0```!L!0``F+G__V4`````0@X0CP)"#AB.`T4.((T$
M0@XHC`5(#C"&!D@..(,'30Y`<@XX00XP00XH0@X@0@X80@X00@X(`!````"T
M!0``P+G__P(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M8"$````````@(0````````````````````````````````````````$`````
M`````0`````````!`````````,L!`````````0`````````:`@````````P`
M````````0!H````````-`````````'17````````&0````````"0JR``````
M`!L`````````"``````````:`````````)BK(```````'``````````(````
M`````/7^_V\`````F`(````````%``````````@-````````!@````````"0
M`P````````H`````````R00````````+`````````!@`````````%0``````
M``````````````,`````````R*T@```````"`````````(@%````````%```
M```````'`````````!<`````````N!0````````'`````````"`3````````
M"`````````"8`0````````D`````````&``````````>``````````@`````
M````^___;P`````!```(`````/[__V\`````H!(```````#___]O``````(`
M````````\/__;P````#2$0```````/G__V\`````!```````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````+BK(```````````````````
M`````````'8:````````AAH```````"6&@```````*8:````````MAH`````
M``#&&@```````-8:````````YAH```````#V&@````````8;````````%AL`
M```````F&P```````#8;````````1AL```````!6&P```````&8;````````
M=AL```````"&&P```````)8;````````IAL```````"V&P```````,8;````
M````UAL```````#F&P```````/8;````````!AP````````6'````````"8<
M````````-AP```````!&'````````%8<````````9AP```````!V'```````
M`(8<````````EAP```````"F'````````+8<````````QAP```````#6'```
M`````.8<````````]AP````````&'0```````!8=````````)AT````````V
M'0```````$8=````````5AT```````!F'0```````'8=````````AAT`````
M``"6'0```````*8=````````MAT```````#&'0```````-8=````````YAT`
M``````#V'0````````8>````````%AX`````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````BP(```````_____P````"@6@```````$=#
M0SH@*%5B=6YT=2`W+C,N,"TQ-W5B=6YT=3$I(#<N,RXP`$=#0SH@*%5B=6YT
M=2`W+C,N,"TQ-G5B=6YT=3,I(#<N,RXP```N<VAS=')T86(`+FEN=&5R<``N
M;F]T92Y!0DDM=&%G`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y
M;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L
M82YD>6X`+G)E;&$N<&QT`"YI;FET`"YP;'0N9V]T`"YT97AT`"YF:6YI`"YR
M;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I
M;FE?87)R87D`+F1A=&$N<F5L+G)O`"YD>6YA;6EC`"YD871A`"YB<W,`+F-O
M;6UE;G0`````````````````````````````````````````````````````
M````````````````````````````````````````"P````$````"````````
M`#@"````````.`(````````<`````````````````````0``````````````
M`````!,````'`````@````````!4`@```````%0"````````(```````````
M``````````0````````````````````A````!P````(`````````=`(`````
M``!T`@```````"0````````````````````$````````````````````-```
M`/;__V\"`````````)@"````````F`(```````#X``````````4`````````
M"````````````````````#X````+`````@````````"0`P```````)`#````
M````>`D````````&`````0````@`````````&`````````!&`````P````(`
M````````"`T````````(#0```````,D$```````````````````!````````
M````````````3@```/___V\"`````````-(1````````TA$```````#*````
M``````4``````````@`````````"`````````%L```#^__]O`@````````"@
M$@```````*`2````````@``````````&`````@````@`````````````````
M``!J````!`````(`````````(!,````````@$P```````)@!````````!0``
M```````(`````````!@`````````=`````0```!"`````````+@4````````
MN!0```````"(!0````````4````7````"``````````8`````````'X````!
M````!@````````!`&@```````$`:````````%P````````````````````0`
M``````````````````!Y`````0````8`````````8!H```````!@&@``````
M`,`#```````````````````0`````````!``````````A`````$````&````
M`````"`>````````(!X````````(````````````````````"``````````(
M`````````(T````!````!@`````````P'@```````#`>````````0CD`````
M`````````````!````````````````````"3`````0````8`````````=%<`
M``````!T5P````````D````````````````````$````````````````````
MF0````$````"`````````(!7````````@%<```````!8/P``````````````
M````"````````````````````*$````!`````@````````#8E@```````-B6
M````````[`````````````````````0```````````````````"O`````0``
M``(`````````R)<```````#(EP```````/@%```````````````````(````
M````````````````N0````X````#`````````)"K(```````D*L````````(
M````````````````````"``````````(`````````,4````/`````P``````
M``"8JR```````)BK````````"`````````````````````@`````````"```
M``````#1`````0````,`````````H*L@``````"@JP```````!,`````````
M```````````0````````````````````W@````8````#`````````+BK(```
M````N*L````````0`@````````8`````````"``````````0`````````(@`
M```!`````P````````#(K2```````,BM````````,`(`````````````````
M``@`````````"`````````#G`````0````,``````````+`@````````L```
M`````"`````````````````````(````````````````````[0````@````#
M`````````""P(```````(+````````"($```````````````````(```````
M`````````````/(````!````,````````````````````""P````````2```
M``````````````````$``````````0`````````!`````P``````````````
M``````````!HL````````/L````````````````````!````````````````
#````
